@@ -4,9 +4,11 @@ from pydantic import BaseModel
 from etsy_apiv3.models.PriceModel import Price
 from etsy_apiv3.models.TransactionModel import Transaction
 from etsy_apiv3.models.ShipmentModel import Shipment
+from etsy_apiv3.models.RefundModel import Refund
 import pycountry
 
 
+
 @dataclass(frozen=True)
 class ReceiptType:
     UNSHIPPED = {"was_paid":True, "was_shipped":False}
@@ -61,7 +63,8 @@ class Receipt(BaseModel):
     gift_wrap_price: Price
     shipments: Optional[List[Shipment]]
     transactions: List[Transaction]
-
+    refunds: List[Refund]
+    
     @property
     def country_name(self):
         return pycountry.countries.get(alpha_2=self.country_iso).name
