@@ -1,8 +1,8 @@
 from __future__ import annotations
 from pydantic import BaseModel
 from typing import List, Optional
-from models.PriceModel import Price
-from models.VariationModel import Variation
+from etsy_apiv3.models.PriceModel import Price
+from etsy_apiv3.models.VariationModel import Variation
 
 class Transaction(BaseModel):
     transaction_id: int
