@@ -1,5 +1,4 @@
 from dataclasses import dataclass
-import json
 from typing import List, Optional
 from etsy_apiv3.models.ListingPropertyModel import ListingProperty
 from etsy_apiv3.utils.APIV3 import EtsyAuth
@@ -91,6 +90,11 @@ class ListingResource:
         response = self.auth.request(endpoint)
         return Inventory(**response)
     
+    def update_listing(self, shop_id: int, listing_id: int, **kwargs):
+        endpoint = f"shops/{shop_id}/listings/{listing_id}"
+        response = self.auth.request(endpoint, "PUT", data=kwargs)
+        return Listing(**response)
+    
     def update_listing_inventory(self, listing_id: int, products: List[dict], price_on_property: Optional[List[int]] = None, quantity_on_property: Optional[List[int]] = None, sku_on_property: Optional[List[int]] = None):
         
         data = {
