@@ -1,7 +1,7 @@
 from dataclasses import dataclass
-from models.ShopModel import Shop
-from utils.APIV3 import EtsyAuth
-from utils.Response import Response
+from etsy_apiv3.models.ShopModel import Shop
+from etsy_apiv3.utils.APIV3 import EtsyAuth
+from etsy_apiv3.utils.Response import Response
 
 @dataclass
 class ShopResource:
