@@ -4,7 +4,6 @@ import requests
 from requests_oauthlib import OAuth2Session
 from etsy_apiv3.utils.RequestException import EtsyRequestException
 from etsy_apiv3.models.UserModel import OtherUser
-from etsy_apiv3.models import Shop
 
 def token_saver(token):
     return token
@@ -38,6 +37,9 @@ class EtsyAuth:
         response = self.request(endpoint)
         return Shop(**response).shop_id
     """
+    @property
+    def self_shop_id(self):
+        return self.session.token.get("access_token").split(".")[0]
     
     def request(self, endpoint: str, method="GET", *args, **kwargs) -> dict:
         """ 
@@ -72,8 +74,6 @@ class EtsyAuth:
 
     
     
-
-
 class EtsySession:
     
     def __init__(self, client_key: str, client_secret: str, token: dict, refresh_url="https://api.etsy.com/v3/public/oauth/token", token_updater: Callable = token_saver):
